@@ -38,12 +38,12 @@
 ## colZ1 : color used to delimit the native extent
 ## colZ2 : color used to delimit the invaded extent
 ##
-## pts2img <- function(pts,extent)
+## ecospat.pts2img <- function(pts,extent)
 ## convert plots into image
 ## pts = points coordinates (2 columns)
 ## extent : grid intervals (2 columns)
 ##
-## fun.arrows(sp1,sp2,clim1,clim2)
+## ecospat.shift.centroids(sp1,sp2,clim1,clim2)
 ## draw arrows linking the centroid of the native and inasive distribution (continuous line) and between native and invaded extent (dashed line)
 ## sp1 : scores of the species native distribution along the the 2 first axes of the PCA
 ## sp2 : scores of the species invasive distribution along the the 2 first axes of the PCA
@@ -103,8 +103,8 @@ ecospat.grid.clim.dyn<-function(glob,glob1,sp,R,th.sp=NULL,th.env=0){
     y<-seq(from=min(glob[,2]),to=max(glob[,2]),length.out=R)				# breaks on score gradient 2
     z<-matrix(sp.dens*nrow(sp)/sum(sp.dens),nrow=R,ncol=R,byrow=F) 			#rescale density to the number of occurrences in sp
     Z<-matrix(glob1.dens*nrow(glob1)/sum(glob1.dens),nrow=R,ncol=R,byrow=F) 	#rescale density to the number of sites in glob1
-    spr<-pts2img(sp,cbind(x,y))
-    glob1r<-pts2img(glob1,cbind(x,y))
+    spr<-ecospat.pts2img(sp,cbind(x,y))
+    glob1r<-ecospat.pts2img(glob1,cbind(x,y))
     if(!is.null(th.sp)){
       z.th<-quantile(as.vector(z[which(spr==1)]),th.sp)
       z[z<z.th]<-0   				#z[z<max(z)/(nrow(sp)/6)]<-0 or z[z<(nrow(sp)^(1/6)*0.005)]<-0 				# remove infinitesimally small number generated by kernel density function
@@ -125,23 +125,77 @@ ecospat.grid.clim.dyn<-function(glob,glob1,sp,R,th.sp=NULL,th.env=0){
 
 ##################################################################################################
 
-ecospat.plot.niche.dyn<-function(z1,z2,quant,title,interest=1,colz1="#00FF0050",colz2="#FF000050",colinter="#0000FF50",colZ1="green3",colZ2="red3")  {
-z<-z1$w+2*z2$w
-if(interest==1){
-  image(z1$x,z1$y,z1$z.uncor,col = gray(100:0 / 100),zlim=c(0.00001,max(z1$z.uncor)),xlab="PC1",ylab="PC2" )
-  image(z1$x,z1$y,z,col = c("#FFFFFF00",colz1,colz2,colinter),add=T )#white, blue, red, green
+ecospat.plot.niche.dyn<-function(z1,z2,quant=0,title,interest=1,colz1="#00FF0050",colz2="#FF000050",colinter="#0000FF50",colZ1="green3",colZ2="red3",name.axis1="environmental gradient 1",name.axis2="environmental gradient 2"){
+
+if(is.null(z1$y)){
+	R<-length(z1$x)
+	x<-z1$x
+	xx<-sort(rep(1:length(x),2))
+
+	y1<-z1$z.uncor/max(z1$z.uncor)
+	Y1<-z1$Z/max(z1$Z)
+	if (quant>0){
+    Y1.quant<-quantile(z1$Z[which(z1$Z>0)],probs=seq(0,1,quant))[2] / max(z1$Z)
+  }else{
+    Y1.quant<-0
   }
-if(interest==2){
-  image(z2$x,z2$y,z2$z.uncor,col = gray(100:0 / 100),zlim=c(0.00001,max(z2$z.uncor)),xlab="PC1",ylab="PC2" )
-  image(z2$x,z2$y,z,col = c("#FFFFFF00",colz1,colz2,colinter),add=T )#white, blue, red, green
+	Y1.quant<-Y1-Y1.quant; Y1.quant[Y1.quant<0]<-0
+	yy1<-sort(rep(1:length(y1),2))[-c(1:2,length(y1)*2)]
+	YY1<-sort(rep(1:length(Y1),2))[-c(1:2,length(Y1)*2)]
+
+	y2<-z2$z.uncor/max(z2$z.uncor)
+	Y2<-z2$Z/max(z2$Z)
+	if (quant>0){
+    Y2.quant<-quantile(z2$Z[which(z2$Z>0)],probs=seq(0,1,quant))[2] / max(z2$Z)
+	}else{
+  Y2.quant=0
+  }
+  Y2.quant<-Y2-Y2.quant; Y2.quant[Y2.quant<0]<-0
+	yy2<-sort(rep(1:length(y2),2))[-c(1:2,length(y2)*2)]
+	YY2<-sort(rep(1:length(Y2),2))[-c(1:2,length(Y2)*2)]
+
+  plot(x,y1,type="n",xlab=name.axis1,ylab="density of occurrence")
+	polygon(x[xx],c(0,y1[yy1],0,0),col=colz1,border=0)
+  polygon(x[xx],c(0,y2[yy2],0,0),col=colz2,border=0)
+	polygon(x[xx],c(0,apply(cbind(y2[yy2],y1[yy1]),1,min,na.exclude=T),0,0),col=colinter,border=0)
+	lines(x[xx],c(0,Y2.quant[YY2],0,0),col=colZ2,lty="dashed")
+	lines(x[xx],c(0,Y1.quant[YY1],0,0),col=colZ1,lty="dashed")
+  lines(x[xx],c(0,Y2[YY2],0,0),col=colZ2)
+	lines(x[xx],c(0,Y1[YY1],0,0),col=colZ1)
+	segments(x0=0,y0=0,x1=max(x[xx]),y1=0,col="white")
+	segments(x0=0,y0=0,x1=0,y1=1,col="white")
+
+  seg.cat<-function(inter,cat,col.unf,col.exp,col.stab){
+    if (inter[3]==0){my.col=0}
+    if (inter[3]==1){my.col=col.unf}
+    if (inter[3]==2){my.col=col.stab}
+    if (inter[3]==-1){my.col=col.exp}
+    segments(x0= inter[1],y0=-0.01,y1=-0.01,x1=inter[2],col=my.col,lwd=4,lty=2)
+  }
+  cat<-ecospat.niche.dyn.index(z1,z2,intersection=quant)$dyn
+  inter<-cbind(z1$x[-length(z1$x)],z1$x[-1],cat[-1])
+  apply(inter,1,seg.cat,col.unf="#00FF0050",col.exp="#FF000050",col.stab="#0000FF50")
+
+}
+if(!is.null(z1$y)){
+
+  z<-z1$w+2*z2$w
+  if(interest==1){
+    image(z1$x,z1$y,z1$z.uncor,col = gray(100:0 / 100),zlim=c(0.00001,max(z1$z.uncor)),xlab=name.axis1,ylab=name.axis2 )
+    image(z1$x,z1$y,z,col = c("#FFFFFF00",colz1,colz2,colinter),add=T )
+    }
+  if(interest==2){
+    image(z2$x,z2$y,z2$z.uncor,col = gray(100:0 / 100),zlim=c(0.00001,max(z2$z.uncor)),xlab=name.axis1,ylab=name.axis2 )
+    image(z2$x,z2$y,z,col = c("#FFFFFF00",colz1,colz2,colinter),add=T )
+    }
+  title(title)
+  contour(z1$x,z1$y,z1$Z,add=T,levels=quantile(z1$Z[z1$Z>0],c(0,quant)),drawlabels=F,lty=c(1,2),col=colZ1)
+  contour(z2$x,z2$y,z2$Z,add=T,levels=quantile(z2$Z[z2$Z>0],c(0,quant)),drawlabels=F,lty=c(1,2),col=colZ2)
   }
-title(title)
-contour(z1$x,z1$y,z1$Z,add=T,levels=quantile(z1$Z[z1$Z>0],c(0,quant)),drawlabels=F,lty=c(1,2),col=colZ1)
-contour(z2$x,z2$y,z2$Z,add=T,levels=quantile(z2$Z[z2$Z>0],c(0,quant)),drawlabels=F,lty=c(1,2),col=colZ2)
 }
 
 
-pts2img <- function(pts,extent){
+ecospat.pts2img <- function(pts,extent){
  img <- matrix(0,nrow=nrow(extent),ncol=nrow(extent))
  x<-findInterval(pts[,1],extent[,1])
  y<-findInterval(pts[,2],extent[,2])
@@ -150,9 +204,17 @@ pts2img <- function(pts,extent){
  return(img)
  }
  
-ecospat.fun.arrows<-function(sp1,sp2,clim1,clim2){
-arrows(median(sp1[,1]),median(sp1[,2]),median(sp2[,1]),median(sp2[,2]),col="red",lwd=2,length=0.1)
-arrows(median(clim1[,1]),median(clim1[,2]),median(clim2[,1]),median(clim2[,2]),lty="11",col="red",lwd=2,length=0.1)
+
+
+ecospat.shift.centroids<-function(sp1,sp2,clim1,clim2,col="red"){
+
+  if (ncol(as.matrix(sp1))==2){
+    arrows(median(sp1[,1]),median(sp1[,2]),median(sp2[,1]),median(sp2[,2]),col="red",lwd=2,length=0.1)
+    arrows(median(clim1[,1]),median(clim1[,2]),median(clim2[,1]),median(clim2[,2]),lty="11",col=col,lwd=2,length=0.1)
+  }else{
+    arrows(median(sp1),0.025,median(sp2),0.025,col="red",lwd=2,length=0.1)
+    arrows(median(clim1),-0.025,median(clim2),-0.025,lty="11",col=col,lwd=2,length=0.1)
+  }
 }
 
 ##################################################################################################
